==> lnl-3.0.0.tar.gz: lnl-3.0.0/src/ver.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: ver.h,v 1.42 2006/01/12 08:51:38 bowkenken Exp $
***************************************************************/

#ifndef	VER_H
#define	VER_H

#define	STR_FILE_NAME_GAME	"lnl"
#define	STR_TITLE	"L&L - Labyrinths & Legends :"
#define	STR_SINCE	"1993"
#define	STR_LATEST	"2006"
#define	STR_AUTHOR	"YOSHIMURA Tomohiko"
#define	STR_HANDLE1	"BowKenKen"
#define	STR_HANDLE2	""
#define	STR_WEB	"http://lnl.sourceforge.jp/"
#define	STR_E_MAIL	"bowkenken@users.sourceforge.jp"
#define	STR_THANKS	"TeaMiKL"

#define	STR_VER_GAME	VERSION

#define	STR_FMT_COPYRIGHT	\
		"--------------------------------" \
		"--------------------------------\n" \
		"%s version %s\n" \
		"Copyright (c) %s-%s %s All rights reserved.\n" \
		"\n" \
		"Created by %s, %s\n" \
		"URL   : %s\n" \
		"E-mail: %s\n" \
		"\n" \
		"Special thanks %s and you.\n" \
		"--------------------------------" \
		"--------------------------------\n" \
		""

#define	LS_STR_COPYRIGHT	\
		STR_TITLE, STR_VER_GAME, \
		STR_SINCE, STR_LATEST, STR_AUTHOR, \
		STR_HANDLE1, \
		STR_HANDLE2, \
		STR_WEB, \
		STR_E_MAIL, \
		STR_THANKS

#endif	/* VER_H */

==> lnl-3.1.2.tar.gz: lnl-3.1.2/src/ver.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: ver.h,v 1.43 2006/08/07 04:33:28 bowkenken Exp $
***************************************************************/

#ifndef	VER_H
#define	VER_H

#define	STR_FILE_NAME_GAME	"lnl"

#define	STR_GAME_TITLE	"L&L - Labyrinths & Legends"
#define	STR_VER_GAME	VERSION

#define	STR_SINCE	"1993"
#define	STR_LATEST	"2006"
#define	STR_AUTHOR	"YOSHIMURA Tomohiko"

#define	STR_WEB	"http://lnl.sourceforge.jp/"
#define	STR_E_MAIL	"bowkenken@users.sourceforge.jp"

#define	STR_TITLE_1	"Created by"
#define	STR_HANDLE_1	"BowKenKen"

#define	STR_TITLE_2	"Character Designer"
#define	STR_HANDLE_2	"[RPG DOT]"

#define	STR_TITLE_THANKS	"Special Thanks"
#define	STR_HANDLE_THANKS	"TeaMiKL and you"

#define	STR_FMT_COPYRIGHT	\
		"--------------------------------" \
		"--------------------------------\n" \
		"%s : version %s\n" \
		"Copyright (c) %s-%s %s All rights reserved.\n" \
		"\n" \
		"URL   : %s\n" \
		"E-mail: %s\n" \
		"\n" \
		"%20s  %s\n" \
		"%20s  %s\n" \
		"%20s  %s\n" \
		"--------------------------------" \
		"--------------------------------\n" \
		""

#define	LS_STR_COPYRIGHT	\
		STR_GAME_TITLE, STR_VER_GAME, \
		STR_SINCE, STR_LATEST, STR_AUTHOR, \
		STR_WEB, \
		STR_E_MAIL, \
		STR_TITLE_1, STR_HANDLE_1, \
		STR_TITLE_2, STR_HANDLE_2, \
		STR_TITLE_THANKS, STR_HANDLE_THANKS

#endif	/* VER_H */
